@@ -44,9 +44,9 @@ FavouritesModel *Library::favourites()
     return new FavouritesModel(std::move(future), this);
 }
 
-void Library::addFavourite(const QString &videoId, const QString &title)
+void Library::addFavourite(const QString &videoId, const QString &title, const QString &artist, const QString &album)
 {
-    connectFuture(addSong(videoId, title), this, [=, this] {
+    connectFuture(addSong(videoId, title, artist, album), this, [=, this] {
         connectFuture(m_database->execute("insert or ignore into favourites (video_id) values (?)", videoId), this, &Library::favouritesChanged);
     });
 }
@@ -66,7 +66,7 @@ FavouriteWatcher *Library::favouriteWatcher(const QString &videoId)
 
 SearchHistoryModel *Library::searches()
 {
-    return new SearchHistoryModel(m_database->getResults<SingleValue<QString>>("select (search_query) from searches order by search_id desc"), this);
+    return new SearchHistoryModel(m_database->getResults<SingleValue<QString>>("select distinct (search_query) from searches order by search_id desc"), this);
 }
 
 void Library::addSearch(const QString &text)
@@ -80,9 +80,9 @@ PlaybackHistoryModel *Library::playbackHistory()
     return new PlaybackHistoryModel(std::move(future), this);
 }
 
-void Library::addPlaybackHistoryItem(const QString &videoId, const QString &title)
+void Library::addPlaybackHistoryItem(const QString &videoId, const QString &title, const QString &artist, const QString &album)
 {
-    connectFuture(addSong(videoId, title), this, [=, this] {
+    connectFuture(addSong(videoId, title, artist, album), this, [=, this] {
         connectFuture(m_database->execute("insert or ignore into played_songs (video_id, plays) values (?, ?)", videoId, 0), this, [=, this] {
             connectFuture(m_database->execute("update played_songs set plays = plays + 1 where video_id = ? ", videoId), this, &Library::playbackHistoryChanged);
         });
@@ -100,9 +100,10 @@ QNetworkAccessManager &Library::nam()
     return m_networkImageCacher;
 }
 
-QFuture<void> Library::addSong(const QString &videoId, const QString &title)
+QFuture<void> Library::addSong(const QString &videoId, const QString &title, const QString &artist, const QString &album)
 {
-    return m_database->execute("insert or ignore into songs (video_id, title, artist, album) values (?, ?, null, null)", videoId, title);
+    // replace is used here to update songs from times when we didn't store artist and album
+    return m_database->execute("insert or replace into songs (video_id, title, artist, album) values (?, ?, ?, ?)", videoId, title, artist, album);
 }
 
 void ThumbnailSource::setVideoId(const QString &id) {
@@ -122,15 +123,32 @@ void ThumbnailSource::setVideoId(const QString &id) {
         return;
     }
 
-    auto future = YTMusicThread::instance()->extractVideoInfo(id);
-    connectFuture(future, this, [this, id, cacheLocation](video_info::VideoInfo &&info) {
-        auto *reply = Library::instance().nam().get(QNetworkRequest(QUrl(QString::fromStdString(info.thumbnail))));
-        connect(reply, &QNetworkReply::finished, this, [id, reply, this, cacheLocation]() {
-            QFile file(cacheLocation);
-            file.open(QFile::WriteOnly);
-            file.write(reply->readAll());
-            setCachedPath(QUrl::fromLocalFile(cacheLocation));
-        });
+    auto *reply = Library::instance().nam().get(QNetworkRequest(QUrl("https://i.ytimg.com/vi_webp/" % m_videoId % "/maxresdefault.webp")));
+
+    auto storeResult = [this, cacheLocation](QNetworkReply *reply) {
+        QFile file(cacheLocation);
+        file.open(QFile::WriteOnly);
+        file.write(reply->readAll());
+        setCachedPath(QUrl::fromLocalFile(cacheLocation));
+
+        reply->deleteLater();
+    };
+
+    connect(reply, &QNetworkReply::errorOccurred, this, [this, storeResult](auto error) {
+        if (error == QNetworkReply::NetworkError::ContentNotFoundError) {
+            qDebug() << "Naive thumbnail resolution failed, falling back to yt-dlp (slower)";
+
+            connectFuture(YTMusicThread::instance()->extractVideoInfo(m_videoId), this, [this, storeResult](auto info) {
+                auto *reply = Library::instance().nam().get(QNetworkRequest(QUrl(QString::fromStdString(info.thumbnail))));
+                connect(reply, &QNetworkReply::finished, this, [reply, storeResult]() {
+                    storeResult(reply);
+                });
+            });
+        }
+    });
+
+    connect(reply, &QNetworkReply::finished, this, [reply, storeResult]() {
+        storeResult(reply);
     });
 }
 
