@@ -3,6 +3,9 @@
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "searchmodel.h"
+#include "playlistutils.h"
+
+#include <ranges>
 
 SearchModel::SearchModel(QObject *parent)
     : AbstractYTMusicModel(parent)
@@ -21,6 +24,7 @@ SearchModel::SearchModel(QObject *parent)
             beginResetModel();
             setLoading(false);
             m_searchResults = results;
+
             endResetModel();
         });
     });
@@ -117,6 +121,24 @@ QVariant SearchModel::data(const QModelIndex &index, int role) const
 
             return QString();
         }, m_searchResults.at(index.row()));
+    case ThumbnailUrl:
+        return std::visit([&](auto &&arg) {
+            using T = std::decay_t<decltype(arg)>;
+
+            if (!arg.thumbnails.empty()) {
+                return QString::fromStdString(arg.thumbnails.front().url);
+            }
+
+            return QString();
+        }, m_searchResults.at(index.row()));
+    case ArtistsDisplayString:
+        return QVariant::fromValue(std::visit([&](auto&& arg) {
+            using T = std::decay_t<decltype(arg)>;
+            if constexpr (std::is_same_v<T, search::Song> || std::is_same_v<T, search::Video> || std::is_same_v<T, search::Album>) {
+                return PlaylistUtils::artistsToString(arg.artists);
+            }
+            return QString();
+        }, m_searchResults.at(index.row())));
     }
 
     Q_UNREACHABLE();
@@ -131,7 +153,9 @@ QHash<int, QByteArray> SearchModel::roleNames() const
         {Type, "type"},
         {VideoId, "videoId"},
         {Artists, "artists"},
+        {ArtistsDisplayString, "artistsDisplayString"},
         {RadioPlaylistId, "radioPlaylistId"},
+        {ThumbnailUrl, "thumbnailUrl"}
     };
 }
 
@@ -153,7 +177,7 @@ void SearchModel::triggerItem(int row)
         if constexpr (std::is_same_v<T, search::Album>) {
             Q_EMIT openAlbum(QString::fromStdString(arg.browse_id));
         } else if constexpr (std::is_same_v<T, search::Artist>) {
-            Q_EMIT openArtist(QString::fromStdString(arg.browse_id));
+            Q_EMIT openArtist(QString::fromStdString(arg.browse_id), QString::fromStdString(arg.radio_id.value_or("")), QString::fromStdString(arg.shuffle_id.value_or("")));
         } else if constexpr (std::is_same_v<T, search::Playlist>) {
             Q_EMIT openPlaylist(QString::fromStdString(arg.browse_id));
         } else if constexpr (std::is_same_v<T, search::Song>) {
