@@ -11,6 +11,8 @@
 #include <QRandomGenerator>
 #include <QFutureWatcher>
 
+#include <iostream>
+
 #include "playlistutils.h"
 
 UserPlaylistModel::UserPlaylistModel(QObject *parent)
@@ -55,6 +57,13 @@ UserPlaylistModel::UserPlaylistModel(QObject *parent)
     connect(&YTMusicThread::instance().get(), &AsyncYTMusic::errorOccurred, this, [this] {
         setLoading(false);
     });
+    connect(this, &UserPlaylistModel::currentVideoIdChanged, this, [this]() {
+        // Clear lyrics, so we won't display old ones if the next song doesn't have any.
+        m_lyrics = {};
+        Q_EMIT lyricsChanged();
+
+        fetchLyrics(m_currentVideoId);
+    });
 }
 
 int UserPlaylistModel::rowCount(const QModelIndex &parent) const
@@ -71,6 +80,8 @@ QVariant UserPlaylistModel::data(const QModelIndex &index, int role) const
         return QString::fromStdString(m_playlist.tracks[index.row()].video_id);
     case Artists:
         return PlaylistUtils::artistsToString(m_playlist.tracks[index.row()].artists);
+    case Album:
+        return QString::fromStdString(m_playlist.tracks[index.row()].album.value_or(meta::Album()).name);
     case IsCurrent:
         return m_playlist.tracks[index.row()].video_id == m_currentVideoId.toStdString();
     }
@@ -86,7 +97,8 @@ QHash<int, QByteArray> UserPlaylistModel::roleNames() const
         {Title, "title"},
         {VideoId, "videoId"},
         {Artists, "artists"},
-        {IsCurrent, "isCurrent"}
+        {Album, "album"},
+        {IsCurrent, "isCurrent"},
     };
 }
 
@@ -129,6 +141,16 @@ void UserPlaylistModel::setCurrentVideoId(const QString &videoId)
     Q_EMIT canSkipChanged();
 }
 
+int UserPlaylistModel::currentIndex() const
+{
+    auto currentTrack = std::find_if(m_playlist.tracks.begin(), m_playlist.tracks.end(),
+                                     [this](const watch::Playlist::Track &track) {
+        return track.video_id == m_currentVideoId.toStdString();
+    });
+
+    return std::distance(m_playlist.tracks.begin(), currentTrack);
+}
+
 bool UserPlaylistModel::canSkip() const
 {
     const auto currentTrackIt = std::find_if(m_playlist.tracks.begin(), m_playlist.tracks.end(),
@@ -271,11 +293,28 @@ void UserPlaylistModel::emitCurrentVideoChanged(const QString &oldVideoId)
     Q_EMIT dataChanged(index(newIndex), index(newIndex), {IsCurrent});
 }
 
+void UserPlaylistModel::fetchLyrics(const QString &videoId)
+{
+    auto future = YTMusicThread::instance()->fetchWatchPlaylist(videoId);
+    connectFuture(future, this, [=, this](const auto &playlist) {
+        if (playlist.lyrics) {
+            connectFuture(YTMusicThread::instance()->fetchLyrics(QString::fromStdString(*playlist.lyrics)), this, [=, this](const auto &lyrics) {
+                m_lyrics = lyrics;
+                Q_EMIT lyricsChanged();
+            });
+        }
+    });
+}
+
 bool UserPlaylistModel::shuffle() const
 {
     return m_shuffle;
 }
 
+QString UserPlaylistModel::lyrics() const {
+    return QString::fromStdString(m_lyrics.lyrics);
+}
+
 void UserPlaylistModel::setShuffle(bool shuffle)
 {
     m_shuffle = shuffle;
