@@ -22,7 +22,7 @@ void pyPrintPretty(py::handle obj) {
 
 #define UNEXPORT __attribute__ ((visibility("hidden")))
 
-constexpr auto TESTED_YTMUSICAPI_VERSION = "0.22.0";
+constexpr auto TESTED_YTMUSICAPI_VERSION = "0.24.0";
 
 struct UNEXPORT YTMusicPrivate {
     py::scoped_interpreter guard {};
@@ -41,10 +41,16 @@ struct UNEXPORT YTMusicPrivate {
             // Some of the called python code randomly fails if the encoding is not utf8
             setenv("LC_ALL", "en_US.utf8", true);
 
-            const auto version = module.attr("_version").attr("__version__").cast<std::string>();
-            if (version != TESTED_YTMUSICAPI_VERSION) {
-                std::cerr << "Running with untested version of ytmusicapi." << std::endl;
+            auto oldVersion = module.attr("__dict__").contains("_version");
+            if (oldVersion) {
+                std::cerr << "Running with outdated and untested version of ytmusicapi." << std::endl;
                 std::cerr << "The currently tested and supported version is " << TESTED_YTMUSICAPI_VERSION << std::endl;
+            } else {
+                const auto version = module.attr("version")("ytmusicapi").cast<std::string>();
+                if (version != TESTED_YTMUSICAPI_VERSION) {
+                    std::cerr << "Running with untested version of ytmusicapi." << std::endl;
+                    std::cerr << "The currently tested and supported version is " << TESTED_YTMUSICAPI_VERSION << std::endl;
+                }
             }
         }
 
@@ -269,7 +275,8 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
                 result["videoId"].cast<std::string>(),
                 result["title"].cast<std::string>(),
                 extract_py_list<meta::Artist>(result["artists"]),
-                result["views"].cast<std::string>()
+                result["views"].cast<std::string>(),
+                extract_py_list<meta::Thumbnail>(result["thumbnails"])
             },
             result["duration"].cast<std::string>()
         };
@@ -279,7 +286,8 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
                 result["videoId"].cast<std::string>(),
                 result["title"].cast<std::string>(),
                 extract_py_list<meta::Artist>(result["artists"]),
-                result["duration"].cast<std::string>()
+                result["duration"].cast<std::string>(),
+                extract_py_list<meta::Thumbnail>(result["thumbnails"])
             },
             extract_meta_album(result["album"]),
             result["isExplicit"].cast<bool>()
@@ -291,21 +299,24 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
             result["type"].cast<std::string>(),
             extract_py_list<meta::Artist>(result["artists"]),
             result["year"].cast<std::optional<std::string>>(),
-            result["isExplicit"].cast<bool>()
+            result["isExplicit"].cast<bool>(),
+            extract_py_list<meta::Thumbnail>(result["thumbnails"])
         };
     } else if (resultType == "playlist") {
         return search::Playlist {
             result["browseId"].cast<std::string>(),
             result["title"].cast<std::string>(),
             result["author"].cast<std::string>(),
-            result["itemCount"].cast<std::string>()
+            result["itemCount"].cast<std::string>(),
+            extract_py_list<meta::Thumbnail>(result["thumbnails"])
         };
     } else if (resultType == "artist") {
         return search::Artist {
             result["browseId"].cast<std::string>(),
             result["artist"].cast<std::string>(),
             optional_key<std::string>(result, "shuffleId"),
-            optional_key<std::string>(result, "radioId")
+            optional_key<std::string>(result, "radioId"),
+            extract_py_list<meta::Thumbnail>(result["thumbnails"])
         };
     } else {
         std::cerr << "Warning: Unsupported search result type found" << std::endl;
@@ -474,16 +485,25 @@ video_info::VideoInfo YTMusic::extract_video_info(const std::string &video_id) c
 
 watch::Playlist YTMusic::get_watch_playlist(const std::optional<std::string> &videoId,
                                             const std::optional<std::string> &playlistId,
-                                            int limit,
-                                            const std::optional<std::string> &params) const
+                                            int limit) const
 {
     const auto playlist = d->get_ytmusic().attr("get_watch_playlist")("videoId"_a = videoId,
                                                                 "playlistId"_a = playlistId,
-                                                                "limit"_a = py::int_(limit),
-                                                                "params"_a = params);
+                                                                "limit"_a = py::int_(limit));
 
     return {
         extract_py_list<watch::Playlist::Track>(playlist["tracks"]),
         playlist["lyrics"].cast<std::optional<std::string>>()
     };
 }
+
+
+Lyrics YTMusic::get_lyrics(const std::string &browse_id) const
+{
+    auto lyrics = d->get_ytmusic().attr("get_lyrics")(browse_id);
+
+    return {
+        lyrics["source"].cast<std::string>(),
+        lyrics["lyrics"].cast<std::string>()
+    };
+}
