@@ -44,6 +44,7 @@ struct Media {
     std::string title;
     std::vector<meta::Artist> artists;
     std::string duration;
+    std::vector<meta::Thumbnail> thumbnails;
 };
 
 struct Video : public Media {
@@ -55,6 +56,7 @@ struct Playlist {
     std::string title;
     std::string author;
     std::string item_count;
+    std::vector<meta::Thumbnail> thumbnails;
 };
 
 struct Song : public Media {
@@ -69,6 +71,7 @@ struct Album {
     std::vector<meta::Artist> artists;
     std::optional<std::string> year;
     bool is_explicit;
+    std::vector<meta::Thumbnail> thumbnails;
 };
 
 struct Artist {
@@ -76,6 +79,7 @@ struct Artist {
     std::string artist;
     std::optional<std::string> shuffle_id;
     std::optional<std::string> radio_id;
+    std::vector<meta::Thumbnail> thumbnails;
 };
 
 using SearchResultItem = std::variant<Video, Playlist, Song, Album, Artist>;
@@ -268,6 +272,11 @@ struct Playlist {
 };
 }
 
+struct Lyrics {
+    std::string source;
+    std::string lyrics;
+};
+
 class YTMusic
 {
 public:
@@ -306,8 +315,9 @@ public:
     /// https://ytmusicapi.readthedocs.io/en/latest/reference.html#ytmusicapi.YTMusic.get_watch_playlist
     watch::Playlist get_watch_playlist(const std::optional<std::string> &videoId = std::nullopt,
                                       const std::optional<std::string> &playlistId = std::nullopt,
-                                      int limit = 25,
-                                      const std::optional<std::string> &params = std::nullopt) const;
+                                      int limit = 25) const;
+
+    Lyrics get_lyrics(const std::string &browse_id) const;
 
     // TODO wrap more methods
 
